;*****************************************************************************/
;
;	PROJECT:	PSOC MORSE DECODER
; 	FILE NAME: 	DISPLAY.ASM
; 	AUTHOR:		Melchor Varela
;
; 	DESCRIPTION
;
;  	Manages all display presentation functions
;
; 	HISTORY
;
;	NAME   	DATE		REMARKS
;
; 	MVM		11OCT2003	Creation
;	ASCII   28NOV2008	Revision
;	DG5MDB	09DEC2008	Release 1.0
;*****************************************************************************/
;*****************************************************************************/
;
;	$Workfile:   display.asm  $
;
;	$Revision:   1.  $
;
;*****************************************************************************/

include 'm8c.inc'
include 'LCD.inc'

;-----------------------------------------------------------------------------
;  Exported interfaces
;-----------------------------------------------------------------------------
export 	_DisplaySetup
export	_DisplayWelcomeMessage
export 	ClearLine0
export 	ClearLine1
export	DisplayTone
export	DisplaySilence
export 	DisplayStatusMsg

;-----------------------------------------------------------------------------
;  Macros
;-----------------------------------------------------------------------------

;-----------------------------------------------------------------------------
;  Defines
;-----------------------------------------------------------------------------

;-----------------------------------------------------------------------------
;  Private data: 
;-----------------------------------------------------------------------------
area 	bss(RAM)

;-----------------------------------------------------------------------------
;  Code: 
;-----------------------------------------------------------------------------
area 	text(ROM,REL)

;-----------------------------------------------------------------------------
;  FUNCTION NAME: DisplaySetup
;
;  DESCRIPTION:
;	Initialises LCD   	  
;
;  ARGUMENTS:
;     none.
;
;  RETURNS:
;     none.
;
;-----------------------------------------------------------------------------
_DisplaySetup:
	lcall	LCD_Start   		; Initialize LCD
	mov     A, 0
	lcall 	LCD_InitVBG  
	ret
	
;-----------------------------------------------------------------------------
;  FUNCTION NAME: DisplayWelcomeMessage
;-----------------------------------------------------------------------------
_DisplayWelcomeMessage:
   	mov 	A, 0	      		; Set row
   	mov  	X, 0	   			; Set col
   	lcall	LCD_Position
   	mov    	A, >Str_Welcome       
   	mov    	X, <Str_Welcome
   	lcall  	LCD_PrCString    
   	
   	mov 	A, 1	      		; Set row
   	mov  	X, 0	   			; Set col
   	lcall	LCD_Position
   	mov    	A, >Str_Welcome1       
   	mov    	X, <Str_Welcome1
   	lcall  	LCD_PrCString    
	ret


;-----------------------------------------------------------------------------
;  FUNCTION NAME: ClearLine0
;-----------------------------------------------------------------------------
ClearLine0:
   	mov 	A, 0  		    	; Set row
   	mov  	X, 0		   		; Set col
   	lcall	LCD_Position
   	mov    	A,>Str_Clear      
   	mov    	X,<Str_Clear
   	lcall  	LCD_PrCString    
	ret

;-----------------------------------------------------------------------------
;  FUNCTION NAME: ClearLine1
;-----------------------------------------------------------------------------
ClearLine1:
   	mov 	A, 1  		    	; Set row
   	mov  	X, 0		   		; Set col
   	lcall	LCD_Position
   	mov    	A,>Str_Clear      
   	mov    	X,<Str_Clear
   	lcall  	LCD_PrCString    
	ret
	
;-----------------------------------------------------------------------------
;  FUNCTION NAME: DisplayTone
;-----------------------------------------------------------------------------
DisplayTone:
   	mov 	A, 1 	     	; Set row
   	mov  	X, 0	   		; Set col
   	lcall	LCD_Position
   	
   	mov    	A, >ToneMsg       
   	mov    	X, <ToneMsg
   	lcall  	LCD_PrCString    
   	
   	call	DisplayStrengthLevel
	ret

;-----------------------------------------------------------------------------
;  FUNCTION NAME: DisplaySilence
;-----------------------------------------------------------------------------
DisplaySilence:
   	mov 	A, 1 	     	; Set row
   	mov  	X, 0	   		; Set col
   	lcall	LCD_Position
   	
   	mov    	A, >SilenceMsg       
   	mov    	X, <SilenceMsg
   	lcall  	LCD_PrCString    
	
   	call	DisplayStrengthLevel
	ret

;-----------------------------------------------------------------------------
;  FUNCTION NAME: DisplayStrengthLevel
;-----------------------------------------------------------------------------
DisplayStrengthLevel:
	mov  	A, [ToneLevel]   	; Set vertical pixel row to define top of vertical bargraph
	asr		A
	asr		A
	asr		A
	push 	A
	mov  	A, 1      			; Set height of bargraph in characters
	push 	A
	mov  	A, 1      			; Set Column position 
	push 	A
	mov  	X, SP      			; Setup data pointer (X)
	dec  	X
	mov  	A, 1      			; Set row position 
	lcall 	LCD_DrawVBG
	add  	SP, -3     			; Restore the stack

	ret
	
;-----------------------------------------------------------------------------
;  FUNCTION NAME: DisplayStatusMsg
;-----------------------------------------------------------------------------
DisplayStatusMsg:	
   								; Presents default status message: WPM: ___
   	mov    	A, 1            
	mov    	X, 3
   	lcall  	LCD_Position
   	
   	mov    	A, >StatusMsg       
   	mov    	X, <StatusMsg
   	lcall  	LCD_PrCString    
	ret
	
;-----------------------------------------------------------------------------
;  String Table
;-----------------------------------------------------------------------------
Str_Welcome:
;		"0123456789012345"	
	DS 	"+ MorseDecoder +"
	DB 	00h   
	
Str_Welcome1:
;		"0123456789012345"	
	DS 	"DG5MdB DG2OG 1.0"
	DB 	00h               
	
Str_Clear:
;		"0123456789012345"	
	DS  "                "
	DB 	00h      

StatusMsg:

	DS 	" WPM: __"
	DB 	00h               
			
SilenceMsg:

	DS 	" "
	DB 	00h               

ToneMsg:

	DS 	"*"
	DB 	00h               
	
